@@ -297,6 +297,13 @@ class Loaf:
         else:
             self.conn.commit()
 
+    # A quick DELETE query.
+    def delete(self, table, where=""):
+        # Sanity check.
+        if table == "":
+            raise Exception("No table specified.")
+        self.query(f"DELETE FROM {table} WHERE {where}")
+
     # Get all values from a table.
     def all(self, table):
         # Sanity check.
